@@ -28,19 +28,23 @@ public:
         std::string shortDescription;
         std::string longDescription;
         std::string maintainer;
+        std::string md5sum, source, fileName;
     };
     Records();
     virtual ~Records();
     const Record &record( entity::Version v );
+    std::string aptTagData( entity::Version v ) const;
     bool preload();
     virtual void setOwnerCache( Cache *c );
 
-    /* pkgRecord conversion */
-    Records( pkgRecords *P );
+    /* pkgRecord conversion
+    Records( pkgRecords *P ); */
     operator pkgRecords*() const {
         return m_records;
     }
 
+    static std::string componentName();
+
 protected:
     typedef std::map<entity::Version,Record> Map;
     typedef std::vector<Map> Vector;
