@@ -5,7 +5,7 @@
 
 #ifndef APTFRONT_INIT_H
 #define APTFRONT_INIT_H
-#include <vector>
+#include <deque>
 
 namespace aptFront {
 
@@ -13,13 +13,13 @@ void init();
 
 struct Init {
     typedef void (*Function)( void );
-    typedef std::vector<Function> FunctionVector;
-    static FunctionVector *s_functions;
+    typedef std::deque<Function> FunctionDeque;
+    static FunctionDeque *s_functions;
     static bool s_globalDone;
     static bool s_done;
     Init( Function f ) {
         if (!s_functions)
-            s_functions = new std::vector<Function>;
+            s_functions = new FunctionDeque();
         s_functions->push_back( f );
     }
 };
