@@ -28,7 +28,7 @@ void to::test<1> ()
     std::list<int> b;
     ensure( a != b );
     Consumer< int > c = consumer< int >( back_inserter( b ) );
-    std::copy( r, r.last(), c );
+    std::copy( r, r.end(), c );
     ensure( a == b );
 }
 
